summaryrefslogtreecommitdiff
path: root/src/mongo/db/service_context.h
diff options
context:
space:
mode:
authorGregory Wlodarek <gregory.wlodarek@mongodb.com>2020-11-12 18:23:34 +0000
committerEvergreen Agent <no-reply@evergreen.mongodb.com>2020-11-13 01:13:53 +0000
commit185000ad894d5cb95a3c946158712054db57cb7a (patch)
tree274e6317aaea9af33aa6160e11e1e57325c4a195 /src/mongo/db/service_context.h
parent911538668252d9885fe3d3859175f2711fb064bc (diff)
downloadmongo-185000ad894d5cb95a3c946158712054db57cb7a.tar.gz
SERVER-48221 Shut down ftdc after storage engine
Diffstat (limited to 'src/mongo/db/service_context.h')
-rw-r--r--src/mongo/db/service_context.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/src/mongo/db/service_context.h b/src/mongo/db/service_context.h
index f59d31ddd49..4b4156a78bf 100644
--- a/src/mongo/db/service_context.h
+++ b/src/mongo/db/service_context.h
@@ -405,9 +405,10 @@ public:
//
/**
* Signal all OperationContext(s) that they have been killed.
*/
- void setKillAllOperations();
+ void setKillAllOperations(const std::set<std::string>& excludedClients = {});
/**
* Reset the operation kill state after a killAllOperations.
@@ -405,9 +405,10 @@ public:
//
/**
- * Signal all OperationContext(s) that they have been killed.
+ * Signal all OperationContext(s) that they have been killed except the ones belonging to the
+ * excluded clients.
*/